@@ -34,17 +34,29 @@
 #include <xfconf/xfconf.h>
 
 #include "common/xfpm-common.h"
+#include "common/xfpm-config.h"
 #include "common/xfpm-icons.h"
 #include "common/xfpm-power-common.h"
+#include "common/xfpm-brightness.h"
 
 #include "battery-button.h"
+#include "scalemenuitem.h"
+
+
+#define SET_LEVEL_TIMEOUT (50)
+#define SAFE_SLIDER_MIN_LEVEL (5)
 
 #define BATTERY_BUTTON_GET_PRIVATE(o) \
 (G_TYPE_INSTANCE_GET_PRIVATE ((o), BATTERY_TYPE_BUTTON, BatteryButtonPrivate))
 
 struct BatteryButtonPrivate
 {
+#ifdef XFCE_PLUGIN
     XfcePanelPlugin *plugin;
+#endif
+#ifdef LXDE_PLUGIN
+    Plugin *plugin;
+#endif
     XfconfChannel   *channel;
 
     UpClient        *upower;
@@ -65,12 +77,14 @@ struct BatteryButtonPrivate
     /* Upower 0.99 has a display device that can be used for the
      * panel image and tooltip description */
     UpDevice        *display_device;
-};
 
-enum
-{
-    PROP_0,
-    PROP_PLUGIN
+    XfpmBrightness  *brightness;
+
+    /* display brightness slider widget */
+    GtkWidget       *range;
+
+    /* filter range value changed events for snappier UI feedback */
+    guint            set_level_timeout;
 };
 
 typedef struct
@@ -91,25 +105,10 @@ static gboolean battery_button_set_icon (BatteryButton *button);
 static gboolean battery_button_press_event (GtkWidget *widget, GdkEventButton *event);
 static void battery_button_show_menu (BatteryButton *button);
 static void battery_button_menu_add_device (BatteryButton *button, BatteryDevice *battery_device, gboolean append);
+static void increase_brightness (BatteryButton *button);
+static void decrease_brightness (BatteryButton *button);
 
 
-static void
-battery_button_set_property (GObject *object,
-				guint prop_id,
-				const GValue *value,
-				GParamSpec   *pspec)
-{
-    BatteryButton *button = BATTERY_BUTTON (object);
-    switch (prop_id)
-    {
-	case PROP_PLUGIN:
-	    button->priv->plugin = XFCE_PANEL_PLUGIN (g_object_ref (g_value_get_object (value)));
-	    break;
-	default:
-	    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-	break;
-    }
-}
 
 static BatteryDevice*
 get_display_device (BatteryButton *button)
@@ -400,6 +399,59 @@ battery_button_add_all_devices (BatteryButton *button)
 #endif
 }
 
+static void
+brightness_up (BatteryButton *button)
+{
+    gint32 level;
+    gint32 max_level;
+
+    xfpm_brightness_get_level (button->priv->brightness, &level);
+    max_level = xfpm_brightness_get_max_level (button->priv->brightness);
+
+    if ( level < max_level )
+    {
+        increase_brightness (button);
+    }
+}
+
+static void
+brightness_down (BatteryButton *button)
+{
+    gint32 level;
+    xfpm_brightness_get_level (button->priv->brightness, &level);
+
+    if ( level > 0 )
+    {
+        decrease_brightness (button);
+    }
+}
+
+static gboolean
+battery_button_scroll_event (GtkWidget *widget, GdkEventScroll *ev)
+{
+    gboolean hw_found;
+    BatteryButton *button;
+
+    button = BATTERY_BUTTON (widget);
+
+    hw_found = xfpm_brightness_has_hw (button->priv->brightness);
+
+    if ( !hw_found )
+        return FALSE;
+
+    if ( ev->direction == GDK_SCROLL_UP )
+    {
+        brightness_up (button);
+        return TRUE;
+    }
+    else if ( ev->direction == GDK_SCROLL_DOWN )
+    {
+        brightness_down (button);
+        return TRUE;
+    }
+    return FALSE;
+}
+
 static void
 battery_button_class_init (BatteryButtonClass *klass)
 {
@@ -407,18 +459,9 @@ battery_button_class_init (BatteryButtonClass *klass)
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     object_class->finalize = battery_button_finalize;
-    object_class->set_property = battery_button_set_property;
 
     widget_class->button_press_event = battery_button_press_event;
-
-    g_object_class_install_property (object_class,
-				     PROP_PLUGIN,
-				     g_param_spec_object ("plugin",
-							  NULL,
-							  NULL,
-							  XFCE_TYPE_PANEL_PLUGIN,
-							  G_PARAM_CONSTRUCT_ONLY |
-							  G_PARAM_WRITABLE));
+    widget_class->scroll_event = battery_button_scroll_event;
 
     g_type_class_add_private (klass, sizeof (BatteryButtonPrivate));
 }
@@ -430,7 +473,14 @@ battery_button_init (BatteryButton *button)
 
     button->priv = BATTERY_BUTTON_GET_PRIVATE (button);
 
+    gtk_widget_set_can_default (GTK_WIDGET (button), FALSE);
+    gtk_widget_set_can_focus (GTK_WIDGET (button), FALSE);
     gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
+    gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
+
+    button->priv->brightness = xfpm_brightness_new ();
+    xfpm_brightness_setup (button->priv->brightness);
+    button->priv->set_level_timeout = 0;
 
     button->priv->upower  = up_client_new ();
     if ( !xfconf_init (&error) )
@@ -440,7 +490,7 @@ battery_button_init (BatteryButton *button)
     }
     else
     {
-	button->priv->channel = xfconf_channel_get ("xfce4-power-manager");
+        button->priv->channel = xfconf_channel_get ("xfce4-power-manager");
     }
 
     /* Sane defaults for the panel icon */
@@ -460,18 +510,39 @@ battery_button_finalize (GObject *object)
 
     g_free(button->priv->panel_icon_name);
 
+    if (button->priv->set_level_timeout)
+    {
+        g_source_remove(button->priv->set_level_timeout);
+        button->priv->set_level_timeout = 0;
+    }
+
     g_signal_handlers_disconnect_by_data (button->priv->upower, button);
 
+#ifdef XFCE_PLUGIN
     g_object_unref (button->priv->plugin);
+#endif
 
     G_OBJECT_CLASS (battery_button_parent_class)->finalize (object);
 }
 
 GtkWidget *
+#ifdef XFCE_PLUGIN
 battery_button_new (XfcePanelPlugin *plugin)
+#endif
+#ifdef LXDE_PLUGIN
+battery_button_new (Plugin *plugin)
+#endif
 {
     BatteryButton *button = NULL;
-    button = g_object_new (BATTERY_TYPE_BUTTON, "plugin", plugin, NULL);
+    button = g_object_new (BATTERY_TYPE_BUTTON, NULL, NULL);
+
+#ifdef XFCE_PLUGIN
+    button->priv->plugin = XFCE_PANEL_PLUGIN (g_object_ref (plugin));
+#endif
+#ifdef LXDE_PLUGIN
+    button->priv->plugin = plugin;
+#endif
+
     return GTK_WIDGET (button);
 }
 
@@ -485,7 +556,7 @@ battery_button_set_icon (BatteryButton *button)
     pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
                                        button->priv->panel_icon_name,
                                        button->priv->panel_icon_width,
-                                       GTK_ICON_LOOKUP_FORCE_SIZE,
+                                       GTK_ICON_LOOKUP_GENERIC_FALLBACK,
                                        NULL);
 
     if ( pixbuf )
@@ -498,6 +569,16 @@ battery_button_set_icon (BatteryButton *button)
     return FALSE;
 }
 
+void
+battery_button_set_width (BatteryButton *button, gint width)
+{
+    g_return_if_fail (BATTERY_IS_BUTTON (button));
+
+    button->priv->panel_icon_width = width;
+
+    battery_button_set_icon (button);
+}
+
 static gboolean
 battery_button_press_event (GtkWidget *widget, GdkEventButton *event)
 {
@@ -508,23 +589,41 @@ battery_button_press_event (GtkWidget *widget, GdkEventButton *event)
     return TRUE;
 }
 
+#ifdef XFCE_PLUGIN
 static gboolean
 battery_button_size_changed_cb (XfcePanelPlugin *plugin, gint size, BatteryButton *button)
 {
-    gint width = size -2 - 2* MAX(gtk_widget_get_style(GTK_WIDGET(button))->xthickness,
-                                  gtk_widget_get_style(GTK_WIDGET(button))->ythickness);
+    gint width;
+    gint xthickness;
+    gint ythickness;
 
-    gtk_widget_set_size_request (GTK_WIDGET(plugin), size, size);
+    g_return_val_if_fail (BATTERY_IS_BUTTON (button), FALSE);
+    g_return_val_if_fail (XFCE_IS_PANEL_PLUGIN (plugin), FALSE);
+
+    xthickness = gtk_widget_get_style(GTK_WIDGET(button))->xthickness;
+    ythickness = gtk_widget_get_style(GTK_WIDGET(button))->ythickness;
+    size /= xfce_panel_plugin_get_nrows (plugin);
+    width = size - 2* MAX (xthickness, ythickness);
+
+    gtk_widget_set_size_request (GTK_WIDGET(plugin), size + xthickness, size + ythickness);
     button->priv->panel_icon_width = width;
 
     return battery_button_set_icon (button);
 }
 
+static void
+battery_button_style_set_cb (XfcePanelPlugin *plugin, GtkStyle *prev_style, BatteryButton *button)
+{
+    gtk_widget_reset_rc_styles (GTK_WIDGET (plugin));
+    battery_button_size_changed_cb (plugin, xfce_panel_plugin_get_size (plugin), button);
+}
+
 static void
 battery_button_free_data_cb (XfcePanelPlugin *plugin, BatteryButton *button)
 {
     gtk_widget_destroy (GTK_WIDGET (button));
 }
+#endif
 
 static void
 help_cb (GtkMenuItem *menuitem, gpointer user_data)
@@ -539,7 +638,10 @@ battery_button_show (BatteryButton *button)
 
     g_return_if_fail (BATTERY_IS_BUTTON (button));
 
+#ifdef XFCE_PLUGIN
     xfce_panel_plugin_add_action_widget (button->priv->plugin, GTK_WIDGET (button));
+    xfce_panel_plugin_set_small (button->priv->plugin, TRUE);
+#endif
 
     button->priv->panel_icon_image = gtk_image_new ();
     gtk_container_add (GTK_CONTAINER (button), button->priv->panel_icon_image);
@@ -550,13 +652,18 @@ battery_button_show (BatteryButton *button)
     gtk_widget_show (mi);
     g_signal_connect (mi, "activate", G_CALLBACK (help_cb), button);
 
+#ifdef XFCE_PLUGIN
     xfce_panel_plugin_menu_insert_item (button->priv->plugin, GTK_MENU_ITEM (mi));
 
     g_signal_connect (button->priv->plugin, "size-changed",
-		      G_CALLBACK (battery_button_size_changed_cb), button);
+                      G_CALLBACK (battery_button_size_changed_cb), button);
+
+    g_signal_connect (button->priv->plugin, "style-set",
+                      G_CALLBACK (battery_button_style_set_cb), button);
 
     g_signal_connect (button->priv->plugin, "free-data",
-		      G_CALLBACK (battery_button_free_data_cb), button);
+                      G_CALLBACK (battery_button_free_data_cb), button);
+#endif
 
     gtk_widget_show_all (GTK_WIDGET(button));
     battery_button_set_tooltip (button);
@@ -572,7 +679,12 @@ menu_destroyed_cb(GtkMenuShell *menu, gpointer user_data)
 
     TRACE("entering");
 
+    /* menu destroyed, range slider is gone */
+    button->priv->range = NULL;
+
+    /* untoggle panel icon */
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), FALSE);
+
     button->priv->menu = NULL;
 }
 
@@ -594,6 +706,25 @@ menu_item_destroyed_cb(GtkWidget *object, gpointer user_data)
     }
 }
 
+static void
+menu_item_activate_cb(GtkWidget *object, gpointer user_data)
+{
+    BatteryButton *button = BATTERY_BUTTON (user_data);
+    GList *item;
+
+    for (item = g_list_first (button->priv->devices); item != NULL; item = g_list_next (item))
+    {
+        BatteryDevice *battery_device = item->data;
+
+        if (battery_device->menu_item == object)
+        {
+            /* Call xfpm settings with the device id */
+            xfpm_preferences_device_id (battery_device->object_path);
+            return;
+        }
+    }
+}
+
 static void
 battery_button_menu_add_device (BatteryButton *button, BatteryDevice *battery_device, gboolean append)
 {
@@ -624,6 +755,9 @@ battery_button_menu_add_device (BatteryButton *button, BatteryDevice *battery_de
     battery_device->menu_item = mi;
     g_signal_connect(G_OBJECT(mi), "destroy", G_CALLBACK(menu_item_destroyed_cb), button);
 
+    /* Active calls xfpm settings with the device's id to display details */
+    g_signal_connect(G_OBJECT(mi), "activate", G_CALLBACK(menu_item_activate_cb), button);
+
     /* Add it to the menu */
     gtk_widget_show(mi);
     if (append)
@@ -632,12 +766,119 @@ battery_button_menu_add_device (BatteryButton *button, BatteryDevice *battery_de
 	gtk_menu_shell_prepend(GTK_MENU_SHELL(button->priv->menu), mi);
 }
 
+static void
+decrease_brightness (BatteryButton *button)
+{
+    gint32 level;
+
+    TRACE("entering");
+
+    if ( !xfpm_brightness_has_hw (button->priv->brightness) )
+        return;
+
+    xfpm_brightness_get_level (button->priv->brightness, &level);
+
+    if ( level > 0 )
+    {
+        xfpm_brightness_down (button->priv->brightness, &level);
+        if (button->priv->range)
+            gtk_range_set_value (GTK_RANGE (button->priv->range), level);
+    }
+}
+
+static void
+increase_brightness (BatteryButton *button)
+{
+    gint32 level, max_level;
+
+    TRACE("entering");
+
+    if ( !xfpm_brightness_has_hw (button->priv->brightness) )
+        return;
+
+    max_level = xfpm_brightness_get_max_level (button->priv->brightness);
+    xfpm_brightness_get_level (button->priv->brightness, &level);
+
+    if ( level < max_level )
+    {
+        xfpm_brightness_up (button->priv->brightness, &level);
+        if (button->priv->range)
+            gtk_range_set_value (GTK_RANGE (button->priv->range), level);
+    }
+}
+
+static gboolean
+brightness_set_level_with_timeout (BatteryButton *button)
+{
+    gint32 range_level, hw_level;
+
+    TRACE("entering");
+
+    range_level = (gint32) gtk_range_get_value (GTK_RANGE (button->priv->range));
+
+    xfpm_brightness_get_level (button->priv->brightness, &hw_level);
+
+    if ( hw_level != range_level )
+    {
+        xfpm_brightness_set_level (button->priv->brightness, range_level);
+    }
+
+    if (button->priv->set_level_timeout)
+    {
+        g_source_remove(button->priv->set_level_timeout);
+        button->priv->set_level_timeout = 0;
+    }
+
+    return FALSE;
+}
+
+static void
+range_value_changed_cb (GtkWidget *widget, BatteryButton *button)
+{
+    TRACE("entering");
+
+    if (button->priv->set_level_timeout)
+        return;
+
+    button->priv->set_level_timeout =
+        g_timeout_add(SET_LEVEL_TIMEOUT,
+                      (GSourceFunc) brightness_set_level_with_timeout, button);
+}
+
+static void
+range_scroll_cb (GtkWidget *widget, GdkEvent *event, BatteryButton *button)
+{
+    GdkEventScroll *scroll_event;
+
+    TRACE("entering");
+
+    scroll_event = (GdkEventScroll*)event;
+
+    if (scroll_event->direction == GDK_SCROLL_UP)
+        increase_brightness (button);
+    else if (scroll_event->direction == GDK_SCROLL_DOWN)
+        decrease_brightness (button);
+}
+
+static void
+range_show_cb (GtkWidget *widget, BatteryButton *button)
+{
+    TRACE("entering");
+    /* Release these grabs they will cause a lockup if pkexec is called
+     * for the brightness helper */
+    gdk_pointer_ungrab(GDK_CURRENT_TIME);
+    gdk_keyboard_ungrab(GDK_CURRENT_TIME);
+    gtk_grab_remove(widget);
+}
+
 static void
 battery_button_show_menu (BatteryButton *button)
 {
-    GtkWidget *menu, *mi;
+    GtkWidget *menu, *mi, *img = NULL;
     GdkScreen *gscreen;
     GList *item;
+    gboolean show_separator_flag = FALSE;
+    gint32 min_level, max_level, current_level = 0;
 
     if(gtk_widget_has_screen(GTK_WIDGET(button)))
         gscreen = gtk_widget_get_screen(GTK_WIDGET(button));
@@ -655,12 +896,74 @@ battery_button_show_menu (BatteryButton *button)
         BatteryDevice *battery_device = item->data;
 
         battery_button_menu_add_device (button, battery_device, TRUE);
+        /* If we add an item to the menu, show the separator */
+        show_separator_flag = TRUE;
     }
 
-    /* separator */
-    mi = gtk_separator_menu_item_new();
-    gtk_widget_show(mi);
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
+    if (show_separator_flag)
+    {
+        /* separator */
+        mi = gtk_separator_menu_item_new();
+        gtk_widget_show(mi);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
+    }
+
+    /* Display brightness slider - show if there's hardware support for it */
+    if ( xfpm_brightness_has_hw (button->priv->brightness) )
+    {
+        GdkPixbuf *pix;
+
+        max_level = xfpm_brightness_get_max_level (button->priv->brightness);
+
+        /* determine minimum value for slider */
+        min_level = xfconf_channel_get_int (button->priv->channel,
+                                            PROPERTIES_PREFIX BRIGHTNESS_SLIDER_MIN_LEVEL,
+                                            -1);
+        if (min_level == -1)
+        {
+            /* Some laptops (and mostly newer ones with intel graphics) can turn off the
+             * backlight completely. If the user is not careful and sets the brightness
+             * very low using the slider, he might not be able to see the screen contents
+             * anymore. Brightness keys do not work on every laptop, so it's better to use
+             * a safe default minimum level that the user can change via the settings
+             * editor if desired.
+             */
+            min_level = (max_level > 100) ? SAFE_SLIDER_MIN_LEVEL : 0;
+            xfconf_channel_set_int (button->priv->channel,
+                                    PROPERTIES_PREFIX BRIGHTNESS_SLIDER_MIN_LEVEL,
+                                    min_level);
+        }
+
+        mi = scale_menu_item_new_with_range (min_level, max_level, 1);
+
+        /* attempt to load and display the brightness icon */
+        pix = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+                                       XFPM_DISPLAY_BRIGHTNESS_ICON,
+                                       button->priv->panel_icon_width,
+                                       GTK_ICON_LOOKUP_FORCE_SIZE,
+                                       NULL);
+        if (pix)
+        {
+            img = gtk_image_new_from_pixbuf (pix);
+            gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(mi), img);
+        }
+
+        scale_menu_item_set_description_label (SCALE_MENU_ITEM(mi), _("<b>Display brightness</b>"));
+
+        /* range slider */
+        button->priv->range = scale_menu_item_get_scale (SCALE_MENU_ITEM (mi));
+
+        /* update the slider to the current brightness level */
+        xfpm_brightness_get_level (button->priv->brightness, &current_level);
+        gtk_range_set_value (GTK_RANGE(button->priv->range), current_level);
+
+        g_signal_connect (mi, "value-changed", G_CALLBACK (range_value_changed_cb), button);
+        g_signal_connect (mi, "scroll-event", G_CALLBACK (range_scroll_cb), button);
+        g_signal_connect (menu, "show", G_CALLBACK (range_show_cb), button);
+
+        gtk_widget_show_all (mi);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
+    }
 
     /* Presentation mode checkbox */
     mi = gtk_check_menu_item_new_with_mnemonic (_("Presentation _mode"));
@@ -668,20 +971,24 @@ battery_button_show_menu (BatteryButton *button)
     gtk_widget_show (mi);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
     xfconf_g_property_bind(button->priv->channel,
-                           "/xfce4-power-manager/presentation-mode",
+                           PROPERTIES_PREFIX PRESENTATION_MODE,
                            G_TYPE_BOOLEAN, G_OBJECT(mi), "active");
 
-    /* Preferences option */
-    mi = gtk_menu_item_new_with_mnemonic (_("_Preferences..."));
+    /* Power manager settings */
+    mi = gtk_menu_item_new_with_mnemonic (_("_Power manager settings..."));
     gtk_widget_show(mi);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
     g_signal_connect(G_OBJECT(mi), "activate", G_CALLBACK(xfpm_preferences), NULL);
 
     gtk_menu_popup (GTK_MENU (menu),
                     NULL,
-		    NULL,
-		    xfce_panel_plugin_position_menu,
-		    button->priv->plugin,
-		    0,
-		    gtk_get_current_event_time ());
+                    NULL,
+#ifdef XFCE_PLUGIN
+                    xfce_panel_plugin_position_menu,
+#else
+                    NULL,
+#endif
+                    button->priv->plugin,
+                    0,
+                    gtk_get_current_event_time ());
 }
