@@ -94,8 +94,6 @@ xfpm_dump (GHashTable *hash)
     gboolean has_hibernate_button;
     gboolean has_power_button;
     gboolean has_lid;
-    gboolean can_spin_down;
-    gboolean devkit_disk;
     
     has_battery = xfpm_string_to_bool (g_hash_table_lookup (hash, "has-battery"));
     has_lid = xfpm_string_to_bool (g_hash_table_lookup (hash, "has-lid"));
@@ -108,8 +106,6 @@ xfpm_dump (GHashTable *hash)
     has_power_button = xfpm_string_to_bool (g_hash_table_lookup (hash, "power-button"));
     has_hibernate_button = xfpm_string_to_bool (g_hash_table_lookup (hash, "hibernate-button"));
     can_shutdown = xfpm_string_to_bool (g_hash_table_lookup (hash, "can-shutdown"));
-    can_spin_down = xfpm_string_to_bool (g_hash_table_lookup (hash, "can-spin"));
-    devkit_disk = xfpm_string_to_bool (g_hash_table_lookup (hash, "devkit-disk"));
 	
     g_print ("---------------------------------------------------\n");
     g_print ("       Xfce power manager version %s\n", VERSION);
@@ -122,11 +118,6 @@ xfpm_dump (GHashTable *hash)
     g_print (_("With network manager support\n"));
 #else
     g_print (_("Without network manager support\n"));
-#endif
-#ifdef HAVE_DPMS
-    g_print (_("With DPMS support\n"));
-#else
-    g_print (_("Without DPMS support\n"));
 #endif
     g_print ("---------------------------------------------------\n");
     g_print ( "%s: %s\n"
@@ -139,23 +130,17 @@ xfpm_dump (GHashTable *hash)
 	      "%s: %s\n"
 	      "%s: %s\n"
 	      "%s: %s\n"
-	      "%s: %s\n"
-	      "%s: %s\n"
 	      "%s: %s\n",
 	     _("Can suspend"),
 	     xfpm_bool_to_local_string (can_suspend),
 	     _("Can hibernate"),
 	     xfpm_bool_to_local_string (can_hibernate),
-	     _("Can spin down hard disks"),
-	     xfpm_bool_to_local_string (devkit_disk),
 	     _("Authorized to suspend"),
 	     xfpm_bool_to_local_string (auth_suspend),
 	     _("Authorized to hibernate"),
 	     xfpm_bool_to_local_string (auth_hibernate),
 	     _("Authorized to shutdown"),
 	     xfpm_bool_to_local_string (can_shutdown),
-	     _("Authorized to spin down hard disks"),
-	     xfpm_bool_to_local_string (can_spin_down),
 	     _("Has battery"),
 	     xfpm_bool_to_local_string (has_battery),
 	     _("Has brightness panel"),
@@ -251,6 +236,7 @@ int main (int argc, char **argv)
     DBusGConnection *bus;
     GError *error = NULL;
     DBusGProxy *proxy;
+    GOptionContext *octx;
      
     gboolean run        = FALSE;
     gboolean quit       = FALSE;
@@ -278,18 +264,46 @@ int main (int argc, char **argv)
 
 #if !GLIB_CHECK_VERSION (2, 32, 0)
     if ( !g_thread_supported () )
-	g_thread_init (NULL);
+        g_thread_init (NULL);
 #endif
 
+    /* Parse the options */
+    octx = g_option_context_new("");
+    g_option_context_set_ignore_unknown_options(octx, TRUE);
+    g_option_context_add_main_entries(octx, option_entries, NULL);
+    g_option_context_add_group(octx, xfce_sm_client_get_option_group(argc, argv));
+    /* We can't add the following command because it will invoke gtk_init
+       before we have a chance to fork.
+       g_option_context_add_group(octx, gtk_get_option_group(TRUE));
+     */
+
+    if(!g_option_context_parse(octx, &argc, &argv, &error)) {
+        g_printerr(_("Failed to parse arguments: %s\n"), error->message);
+        g_option_context_free(octx);
+        g_error_free(error);
+
+        return EXIT_FAILURE;
+    }
+
+    g_option_context_free(octx);
+
+    /* Fork if needed */
+    if ( dump == FALSE && debug == FALSE && no_daemon == FALSE && daemon(0,0) )
+    {
+        g_critical ("Could not daemonize");
+    }
+
+
+    /* Initialize */
     dbus_g_thread_init ();
 
     xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
-    
+
     g_set_application_name (PACKAGE_NAME);
-    
-    if (!gtk_init_with_args (&argc, &argv, (gchar *)"", option_entries, (gchar *)PACKAGE, &error)) 
+
+    if (!gtk_init_check (&argc, &argv))
     {
-        if (G_LIKELY (error)) 
+        if (G_LIKELY (error))
         {
             g_printerr ("%s: %s.\n", G_LOG_DOMAIN, error->message);
             g_printerr (_("Type '%s --help' for usage."), G_LOG_DOMAIN);
@@ -299,22 +313,17 @@ int main (int argc, char **argv)
         else
         {
             g_error ("Unable to open display.");
-	}
+        }
 
         return EXIT_FAILURE;
     }
-    
+
     if ( version )    
     {
-	show_version ();
+        show_version ();
     }
     
     xfpm_debug_init (debug);
-
-    if ( dump == FALSE && debug == FALSE && no_daemon == FALSE && daemon(0,0) )
-    {
-	g_critical ("Could not daemonize");
-    }
     
     bus = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
             
