@@ -44,7 +44,6 @@
 
 #include "xfpm-power.h"
 #include "xfpm-dbus.h"
-#include "xfpm-disks.h"
 #include "xfpm-dpms.h"
 #include "xfpm-manager.h"
 #include "xfpm-console-kit.h"
@@ -92,12 +91,10 @@ struct XfpmManagerPrivate
     XfpmConsoleKit     *console;
     XfpmSystemd        *systemd;
     XfpmDBusMonitor    *monitor;
-    XfpmDisks          *disks;
     XfpmInhibit        *inhibit;
     EggIdletime        *idle;
-#ifdef HAVE_DPMS
+
     XfpmDpms           *dpms;
-#endif
 
     GTimer	       *timer;
 
@@ -151,15 +148,12 @@ xfpm_manager_finalize (GObject *object)
     if ( manager->priv->console != NULL )
         g_object_unref (manager->priv->console);
     g_object_unref (manager->priv->monitor);
-    g_object_unref (manager->priv->disks);
     g_object_unref (manager->priv->inhibit);
     g_object_unref (manager->priv->idle);
 
     g_timer_destroy (manager->priv->timer);
 
-#ifdef HAVE_DPMS
     g_object_unref (manager->priv->dpms);
-#endif
 
     g_object_unref (manager->priv->backlight);
 
@@ -359,10 +353,8 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
 
 	if ( action == LID_TRIGGER_NOTHING )
 	{
-#ifdef HAVE_DPMS
 	    if ( !xfpm_is_multihead_connected () )
 		xfpm_dpms_force_level (manager->priv->dpms, DPMSModeOff);
-#endif
 	}
 	else if ( action == LID_TRIGGER_LOCK_SCREEN )
 	{
@@ -391,9 +383,8 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
     else
     {
 	XFPM_DEBUG_ENUM (action, XFPM_TYPE_LID_TRIGGER_ACTION, "LID opened");
-#ifdef HAVE_DPMS
+
 	xfpm_dpms_force_level (manager->priv->dpms, DPMSModeOn);
-#endif
     }
 }
 
@@ -413,8 +404,7 @@ xfpm_manager_alarm_timeout_cb (EggIdletime *idle, guint id, XfpmManager *manager
 
     if ( id == TIMEOUT_INACTIVITY_ON_AC || id == TIMEOUT_INACTIVITY_ON_BATTERY )
     {
-	XfpmShutdownRequest req = XFPM_DO_NOTHING;
-	gchar *sleep_mode;
+	XfpmShutdownRequest sleep_mode = XFPM_DO_NOTHING;
 	gboolean on_battery;
 
 	if ( manager->priv->inhibited )
@@ -423,25 +413,23 @@ xfpm_manager_alarm_timeout_cb (EggIdletime *idle, guint id, XfpmManager *manager
 	    return;
 	}
 
-	g_object_get (G_OBJECT (manager->priv->conf),
-		      INACTIVITY_SLEEP_MODE, &sleep_mode,
-		      NULL);
+    if ( id == TIMEOUT_INACTIVITY_ON_AC)
+        g_object_get (G_OBJECT (manager->priv->conf),
+                      INACTIVITY_SLEEP_MODE_ON_AC, &sleep_mode,
+                      NULL);
+    else
+        g_object_get (G_OBJECT (manager->priv->conf),
+                      INACTIVITY_SLEEP_MODE_ON_BATTERY, &sleep_mode,
+                      NULL);
 
 	g_object_get (G_OBJECT (manager->priv->power),
 		      "on-battery", &on_battery,
 		      NULL);
 
-	if ( !g_strcmp0 (sleep_mode, "Suspend") )
-	    req = XFPM_DO_SUSPEND;
-	else
-	    req = XFPM_DO_HIBERNATE;
-
-	g_free (sleep_mode);
-
 	if ( id == TIMEOUT_INACTIVITY_ON_AC && on_battery == FALSE )
-	    xfpm_manager_sleep_request (manager, req, FALSE);
+	    xfpm_manager_sleep_request (manager, sleep_mode, FALSE);
 	else if ( id ==  TIMEOUT_INACTIVITY_ON_BATTERY && on_battery  )
-	    xfpm_manager_sleep_request (manager, req, FALSE);
+	    xfpm_manager_sleep_request (manager, sleep_mode, FALSE);
     }
 }
 
@@ -699,7 +687,6 @@ void xfpm_manager_start (XfpmManager *manager)
         manager->priv->console = xfpm_console_kit_new ();
 
     manager->priv->monitor = xfpm_dbus_monitor_new ();
-    manager->priv->disks = xfpm_disks_new ();
     manager->priv->inhibit = xfpm_inhibit_new ();
     manager->priv->idle = egg_idletime_new ();
 
@@ -747,9 +734,7 @@ void xfpm_manager_start (XfpmManager *manager)
 
     manager->priv->kbd_backlight = xfpm_kbd_backlight_new ();
 
-#ifdef HAVE_DPMS
     manager->priv->dpms = xfpm_dpms_new ();
-#endif
 
     g_signal_connect (manager->priv->button, "button_pressed",
 		      G_CALLBACK (xfpm_manager_button_pressed_cb), manager);
@@ -799,8 +784,6 @@ GHashTable *xfpm_manager_get_config (XfpmManager *manager)
     gboolean has_lcd_brightness = TRUE;
     gboolean can_shutdown = TRUE;
     gboolean has_lid = FALSE;
-    gboolean can_spin = FALSE;
-    gboolean devkit_disk = FALSE;
 
     hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
@@ -825,9 +808,6 @@ GHashTable *xfpm_manager_get_config (XfpmManager *manager)
 		  "has-lid", &has_lid,
 		  NULL);
 
-    can_spin = xfpm_disks_get_can_spin (manager->priv->disks);
-    devkit_disk = xfpm_disks_kit_is_running (manager->priv->disks);
-
     has_battery = xfpm_power_has_battery (manager->priv->power);
     has_lcd_brightness = xfpm_backlight_has_hw (manager->priv->backlight);
 
@@ -851,8 +831,6 @@ GHashTable *xfpm_manager_get_config (XfpmManager *manager)
 
     g_hash_table_insert (hash, g_strdup ("has-battery"), g_strdup (xfpm_bool_to_string (has_battery)));
     g_hash_table_insert (hash, g_strdup ("has-lid"), g_strdup (xfpm_bool_to_string (has_lid)));
-    g_hash_table_insert (hash, g_strdup ("can-spin"), g_strdup (xfpm_bool_to_string (can_spin)));
-    g_hash_table_insert (hash, g_strdup ("devkit-disk"), g_strdup (xfpm_bool_to_string (devkit_disk)));
 
     g_hash_table_insert (hash, g_strdup ("has-brightness"), g_strdup (xfpm_bool_to_string (has_lcd_brightness)));
 
