@@ -57,11 +57,10 @@ enum
     PROP_0,
     PROP_GENERAL_NOTIFICATION,
     PROP_LOCK_SCREEN_ON_SLEEP,
-    PROP_POWER_SAVE_ON_BATTERY,
     PROP_ENABLE_CPU_FREQ,
     PROP_CRITICAL_LEVEL,
     PROP_SHOW_BRIGHTNESS_POPUP,
-    PROP_ENABLE_BRIGHTNESS,
+    PROP_HANDLE_BRIGHTNESS_KEYS,
     PROP_TRAY_ICON,
     PROP_CRITICAL_BATTERY_ACTION,
     PROP_POWER_BUTTON,
@@ -71,22 +70,21 @@ enum
     PROP_LID_ACTION_ON_BATTERY,
     PROP_BRIGHTNESS_LEVEL_ON_AC,
     PROP_BRIGHTNESS_LEVEL_ON_BATTERY,
-#ifdef HAVE_DPMS
+    PROP_BRIGHTNESS_SLIDER_MIN_LEVEL,
+
     PROP_ENABLE_DPMS,
     PROP_DPMS_SLEEP_ON_AC,
     PROP_DPMS_OFF_ON_AC,
     PROP_DPMS_SLEEP_ON_BATTERY,
     PROP_DPMS_OFF_ON_BATTERY,
     PROP_DPMS_SLEEP_MODE,
-#endif
+
     PROP_IDLE_ON_AC,
     PROP_IDLE_ON_BATTERY,
-    PROP_IDLE_SLEEP_MODE,
+    PROP_IDLE_SLEEP_MODE_ON_AC,
+    PROP_IDLE_SLEEP_MODE_ON_BATTERY,
     PROP_DIM_ON_AC_TIMEOUT,
     PROP_DIM_ON_BATTERY_TIMEOUT,
-    PROP_SPIN_DOWN_DISK,
-    PROP_SPIN_DOWN_DISK_ON_AC_TIMEOUT,
-    PROP_SPIN_DOWN_DISK_ON_BATTERY_TIMEOUT,
 #ifdef WITH_NETWORK_MANAGER
     PROP_NETWORK_MANAGER_SLEEP,
 #endif
@@ -191,8 +189,15 @@ xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
     if ( !g_str_has_prefix (property, PROPERTIES_PREFIX) || strlen (property) <= strlen (PROPERTIES_PREFIX) )
 	return;
 
-    /* We handle presentation mode in xfpm-power directly */
-    if ( g_strcmp0 (property, "/xfce4-power-manager/presentation-mode") == 0 )
+    /* We handle presentation mode and blank-times in xfpm-power directly */
+    if ( g_strcmp0 (property, PROPERTIES_PREFIX PRESENTATION_MODE) == 0 ||
+         g_strcmp0 (property, PROPERTIES_PREFIX ON_AC_BLANK) == 0 ||
+         g_strcmp0 (property, PROPERTIES_PREFIX ON_BATTERY_BLANK) == 0)
+        return;
+
+    /* We handle brightness switch in xfpm-backlight directly */
+    if ( g_strcmp0 (property, PROPERTIES_PREFIX BRIGHTNESS_SWITCH) == 0 ||
+         g_strcmp0 (property, PROPERTIES_PREFIX BRIGHTNESS_SWITCH_SAVE) == 0 )
         return;
 
     XFPM_DEBUG ("Property modified: %s\n", property);
@@ -254,15 +259,6 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                            TRUE,
                                                            G_PARAM_READWRITE));
     
-    /**
-     * XfpmXfconf::power-save-on-battery
-     **/
-    g_object_class_install_property (object_class,
-                                     PROP_POWER_SAVE_ON_BATTERY,
-                                     g_param_spec_boolean (POWER_SAVE_ON_BATTERY,
-                                                           NULL, NULL,
-                                                           TRUE,
-                                                           G_PARAM_READWRITE));
     /**
      * XfpmXfconf::enable-cpu-freq-control
      **/
@@ -295,11 +291,11 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                            G_PARAM_READWRITE));
     
     /**
-     * XfpmXfconf::show-brightness-popup
+     * XfpmXfconf::handle-brightness-keys
      **/
     g_object_class_install_property (object_class,
-                                     PROP_ENABLE_BRIGHTNESS,
-                                     g_param_spec_boolean (ENABLE_BRIGHTNESS_CONTROL,
+                                     PROP_HANDLE_BRIGHTNESS_KEYS,
+                                     g_param_spec_boolean (HANDLE_BRIGHTNESS_KEYS,
                                                            NULL, NULL,
                                                            TRUE,
                                                            G_PARAM_READWRITE));
@@ -409,7 +405,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
 							LID_TRIGGER_LOCK_SCREEN,
 							LID_TRIGGER_LOCK_SCREEN,
                                                         G_PARAM_READWRITE));
-#ifdef HAVE_DPMS
+
     /**
      * XfpmXfconf::dpms-enabled
      **/
@@ -472,7 +468,6 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                            NULL, NULL,
                                                            "Standby",
                                                            G_PARAM_READWRITE));
-#endif /* HAVE_DPMS */
 
     /**
      * XfpmXfconf::inactivity-on-ac
@@ -498,15 +493,30 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
 							14,
                                                         G_PARAM_READWRITE));
 
-     /**
-     * XfpmXfconf::inactivity-sleep-mode
+    /**
+     * XfpmXfconf::inactivity-sleep-mode-on-battery
      **/
     g_object_class_install_property (object_class,
-                                     PROP_IDLE_SLEEP_MODE,
-                                     g_param_spec_string (INACTIVITY_SLEEP_MODE,
-                                                          NULL, NULL,
-							  "Suspend",
-                                                          G_PARAM_READWRITE));
+                                     PROP_IDLE_SLEEP_MODE_ON_BATTERY,
+                                     g_param_spec_uint (INACTIVITY_SLEEP_MODE_ON_BATTERY,
+                                                        NULL, NULL,
+                                                        XFPM_DO_SUSPEND,
+                                                        XFPM_DO_HIBERNATE,
+                                                        XFPM_DO_HIBERNATE,
+                                                        G_PARAM_READWRITE));
+
+    /**
+     * XfpmXfconf::inactivity-sleep-mode-on-ac
+     **/
+    g_object_class_install_property (object_class,
+                                     PROP_IDLE_SLEEP_MODE_ON_AC,
+                                     g_param_spec_uint (INACTIVITY_SLEEP_MODE_ON_AC,
+                                                        NULL, NULL,
+                                                        XFPM_DO_SUSPEND,
+                                                        XFPM_DO_HIBERNATE,
+                                                        XFPM_DO_SUSPEND,
+                                                        G_PARAM_READWRITE));
+
     /**
      * XfpmXfconf::brightness-on-ac
      **/
@@ -531,41 +541,18 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
 							120,
                                                         G_PARAM_READWRITE));
 
-    /**
-     * XfpmXfconf::spin-down-hdd
-     **/
-    g_object_class_install_property (object_class,
-                                     PROP_SPIN_DOWN_DISK,
-                                     g_param_spec_uint (SPIN_DOWN_HDD,
-                                                           NULL, NULL,
-							0,
-							G_MAXUINT16,
-							4,
-                                                           G_PARAM_READWRITE));
 
     /**
-     * XfpmXfconf::spin-down-on-ac-timeout
+     * XfpmXfconf::brightness-slider-min-level
      **/
     g_object_class_install_property (object_class,
-                                     PROP_SPIN_DOWN_DISK_ON_AC_TIMEOUT,
-                                     g_param_spec_uint (SPIN_DOWN_ON_AC_TIMEOUT,
-                                                        NULL, NULL,
-							800,
-							G_MAXUINT,
-							800,
-                                                        G_PARAM_READWRITE));
-
-    /**
-     * XfpmXfconf::spin-down-on-battery-timeout
-     **/
-    g_object_class_install_property (object_class,
-                                     PROP_SPIN_DOWN_DISK_ON_BATTERY_TIMEOUT,
-                                     g_param_spec_uint (SPIN_DOWN_ON_BATTERY_TIMEOUT,
-                                                        NULL, NULL,
-							120,
-							G_MAXUINT,
-							120,
-                                                        G_PARAM_READWRITE));
+                                     PROP_BRIGHTNESS_SLIDER_MIN_LEVEL,
+                                     g_param_spec_int (BRIGHTNESS_SLIDER_MIN_LEVEL,
+                                                       NULL, NULL,
+                                                       -1,
+                                                       G_MAXINT32,
+                                                       -1,
+                                                       G_PARAM_READWRITE));
 
 #ifdef WITH_NETWORK_MANAGER
     /**
